@@ -2,11 +2,13 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from asyncio import TimerHandle, ensure_future, get_event_loop
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Sequence, TypeVar
+from typing import TYPE_CHECKING, Awaitable, Callable, Sequence, TypeVar
+
+from hikari import StartedEvent
 
 from crescent.bot import Bot
 from crescent.exceptions import CrescentException
-from crescent.internal.meta_struct import MetaStruct
+from crescent.internal.includable import Includable
 
 if TYPE_CHECKING:
     from asyncio import AbstractEventLoop
@@ -22,7 +24,7 @@ class TaskError(CrescentException):
 
 class Task(ABC):
     def __init__(self, callback: TaskCallbackT) -> None:
-        self.event_loop: AbstractEventLoop = get_event_loop()
+        self.event_loop: AbstractEventLoop | None = None
         self.callback = callback
         self.timer_handle: TimerHandle | None = None
         self.app: Bot | None = None
@@ -30,13 +32,13 @@ class Task(ABC):
     def start(self) -> None:
         if self.running:
             raise TaskError("Task is already running.")
+
+        self.event_loop = get_event_loop()
         ensure_future(self._start_inner())
 
     async def _start_inner(self) -> None:
         assert self.app is not None
 
-        await self.app.started.wait()
-
         self._call_next()
 
     def stop(self) -> None:
@@ -54,6 +56,7 @@ class Task(ABC):
         self._call_next()
 
     def _call_next(self) -> None:
+        assert self.event_loop
         self.timer_handle = self.event_loop.call_later(self._next_iteration(), self._call_async)
 
     @abstractmethod
@@ -62,19 +65,27 @@ class Task(ABC):
         ...
 
     @staticmethod
-    def _link(meta: MetaStruct[Any, _TaskType]) -> None:
-        """Sets hooks on MetaStruct required for Task to function properly."""
-        meta.app_set_hooks.append(_on_app_set)
-        meta.plugin_unload_hooks.append(_unload)
+    def _link(includable: Includable[_TaskType]) -> None:
+        """Sets hooks on Includable required for Task to function properly."""
+        includable.app_set_hooks.append(_on_app_set)
+        includable.plugin_unload_hooks.append(_unload)
 
 
 _TaskType = TypeVar("_TaskType", bound=Task)
 
 
-def _on_app_set(self: MetaStruct[TaskCallbackT, _TaskType]) -> None:
+def _on_app_set(self: Includable[_TaskType]) -> None:
     self.metadata.app = self.app
-    self.metadata.start()
+
+    async def callback(_: StartedEvent) -> None:
+        self.metadata.start()
+        self.app.unsubscribe(StartedEvent, callback)
+
+    if not self.app.started.is_set():
+        self.app.subscribe(StartedEvent, callback)
+    else:
+        self.metadata.start()
 
 
-def _unload(self: MetaStruct[TaskCallbackT, _TaskType]) -> None:
+def _unload(self: Includable[_TaskType]) -> None:
     self.metadata.stop()
